@@ -11,6 +11,9 @@
  * act poorly
  */
 
+#ifdef Windows
+#include <Windows.h>
+#endif
 #include <sys/types.h>
 #include <stdio.h>
 #include <sys/file.h>
@@ -29,7 +32,7 @@
 #include <stdlib.h>
 #endif
 
-#if ((defined(solaris) && defined( __LP64__ )) || defined(__s390x__))
+#if (defined(solaris) && defined( __LP64__ )) || defined(__s390x__) || defined(FreeBSD)
 /* If we are building for 64-bit Solaris, all functions that return pointers
  * must be declared before they are used; otherwise the compiler will assume
  * that they return ints and the top 32 bits of the pointer will be lost,
@@ -88,7 +91,7 @@ void do_label(int,char *,int,int);
 /*	  column							*/
 /************************************************************************/
 
-char libbif_version[] = "Libbif Version $Revision: 3.23 $";
+char libbif_version[] = "Libbif Version $Revision: 3.25 $";
 void do_eof(int );		/* Used internally */
 void do_header(int );		/* Used internally */
 int endian(void);
